import BN from "bn.js";
import { TransactionSuccessStatus } from "../../types/genericMccTypes";
import { IUtxoGetTransactionRes } from "../../types/utxoTypes";
import { AddressAmount, BalanceDecreasingSummaryResponse, PaymentSummaryProps, PaymentSummaryResponse, TransactionBase } from "../TransactionBase";
export declare type UtxoTransactionTypeOptions = "coinbase" | "payment";
export declare abstract class UtxoTransaction extends TransactionBase<IUtxoGetTransactionRes> {
    protected get data(): IUtxoGetTransactionRes;
    get txid(): string;
    get stdTxid(): string;
    get reference(): string[];
    get stdPaymentReference(): string;
    get unixTimestamp(): number;
    get sourceAddresses(): (string | undefined)[];
    get receivingAddresses(): (string | undefined)[];
    toBnValue(value: number | undefined): BN;
    get fee(): BN;
    get feeSignerTotalAmount(): AddressAmount;
    get spentAmounts(): AddressAmount[];
    get intendedSpentAmounts(): AddressAmount[];
    get receivedAmounts(): AddressAmount[];
    get intendedReceivedAmounts(): AddressAmount[];
    get type(): UtxoTransactionTypeOptions;
    get isNativePayment(): boolean;
    get successStatus(): TransactionSuccessStatus;
    paymentSummary({ inUtxo, outUtxo }: PaymentSummaryProps): PaymentSummaryResponse;
    balanceDecreasingSummary(sourceAddressIndicator: string): BalanceDecreasingSummaryResponse;
    /**
     * Asserts whether the vin index is in valid range. If not, exception is thrown.
     * @param vinIndex vin index
     */
    assertValidVinIndex(vinIndex: number): void;
    /**
     * Asserts whether the vout index is in valid range. If not, exception is thrown.
     * @param voutIndex vout index
     */
    assertValidVoutIndex(voutIndex: number): void;
}
//# sourceMappingURL=UtxoTransaction.d.ts.map