import BN from "bn.js";
import { TransactionSuccessStatus } from "../../../types";
import { BtcTxData } from "../txDataTypes/UtxoNodeTxData";
import { AddressAmount, BalanceDecreasingProps, BalanceDecreasingSummaryResponse, PaymentSummaryProps, PaymentSummaryResponse, TxBaseFull } from "./TxBase";
export declare type UtxoTransactionTypeOptions = "coinbase" | "payment";
export declare abstract class UtxoFullTransaction extends TxBaseFull<BtcTxData> {
    get type(): UtxoTransactionTypeOptions;
    get isNativePayment(): boolean;
    get txid(): string;
    get stdTxid(): string;
    get reference(): string[];
    get stdPaymentReference(): string;
    get unixTimestamp(): number;
    get successStatus(): TransactionSuccessStatus;
    get sourceAddresses(): (string | undefined)[];
    toBnValue(value: number | undefined): BN;
    get spentAmounts(): AddressAmount[];
    get intendedSpentAmounts(): AddressAmount[];
    get receivingAddresses(): (string | undefined)[];
    get receivedAmounts(): AddressAmount[];
    get intendedReceivedAmounts(): AddressAmount[];
    /**
     * Asserts whether the vin index is in valid range. If not, exception is thrown.
     * @param vinIndex vin index
     */
    assertValidVinIndex(vinIndex: number): void;
    /**
     * Asserts whether the vout index is in valid range. If not, exception is thrown.
     * @param voutIndex vout index
     */
    assertValidVoutIndex(voutIndex: number): void;
    paymentSummary({ inUtxo, outUtxo }: PaymentSummaryProps): PaymentSummaryResponse;
    balanceDecreasingSummary({ sourceAddressIndicator }: BalanceDecreasingProps): BalanceDecreasingSummaryResponse;
    get hash(): string;
}
//# sourceMappingURL=UtxoTrancation.d.ts.map